dependencies = {
    "a": [],
    "accordion": [],
    "alert": [],
    "alert_dialog": ["button"],
    "badge": [],
    "button": [],
    "card": [],
    "command": [],
    "dialog": ["button"],
    "checkbox": [],
    "dropdown_menu": [],
    "form": ["label"],
    "input": [],
    "label": [],
    "progress": [],
    "table": [],
    "tabs": [],
    "toast": ["button"],
    "textarea": [],
}
